[][src]Struct edge_detection::Edge

pub struct Edge { /* fields omitted */ }

The computed result for a single pixel.

Methods

impl Edge[src]

pub fn angle(&self) -> f32[src]

The direction of the gradient in radians.

This is a convenience function for atan2(direction).

pub fn dir(&self) -> (f32, f32)[src]

Returns the direction of the edge scaled by it's magnitude.

pub fn dir_norm(&self) -> (f32, f32)[src]

Returns a normalized vector of the direction of the change in brightness

The vector will point away from the detected line. E.g. a vertical line separating a dark area on the left and light area on the right will have it's direction point towards the light area on the right.

pub fn magnitude(&self) -> f32[src]

The absolute magnitude of the change in brightness.

Between 0 and 1 inclusive.