[−][src]Struct edge_detection::Detection
The result of a computation.
Methods
impl Detection[src]
pub fn width(&self) -> usize[src]
Returns the width of the computed image.
pub fn height(&self) -> usize[src]
Returns the height of the computed image.
pub fn interpolate(&self, x: f32, y: f32) -> Edge[src]
Linearly interpolates the edge at the specified location.
Similar to as if the edges detection were continuous.
pub fn as_image(&self) -> DynamicImage[src]
Renders the detected edges to an image.
The intensity of the pixel represents the magnitude of the change in brightnes while the color represents the direction.
Useful for debugging.